@@ -11,6 +11,7 @@ import datetime
 import logging
 import re
 import sys
+import time
 from decimal import Decimal
 from io import BytesIO
 from itertools import islice
@@ -128,7 +129,7 @@ class Connection(object):
 
         if port is None:
             port = 9000
-        self._transport = TSocket.TSocket(host, port, socket_keepalive=True)
+        self._transport = TSocket.TSocket(host, port)
         self._transport = TTransport.TBufferedTransport(self._transport)
 
         protocol = TBinaryProtocol.TBinaryProtocol(self._transport)
@@ -157,6 +158,9 @@ class Connection(object):
         self._client.clear(query_id)
         self._transport.close()
 
+    def check_connection(self):
+        return self._transport.isOpen()
+
     def clear(self, query_id):
         self._client.clear(query_id)
 
@@ -338,11 +342,8 @@ class Cursor(DBAPICursor):
         return self._data
 
     def _fetch_all(self):
-        # _logger.info("fetching all from overriden method")
         self._data = list()
         while True:
-            # _logger.info(len(self._data))
-            # _logger.info("fetching next batch from fetch all")
             rows = self.fetch_batch()
             if rows is None:
                 break
@@ -364,7 +365,6 @@ class Cursor(DBAPICursor):
         return read_rows_from_batch(self._query_columns_description, dis)
 
     def fetchall(self):
-        # _logger.info("fetching all")
         return self._fetch_all()
 
     def fetchmany(self, size=None):
@@ -427,11 +427,11 @@ class Error(Exception):
 
 
 if __name__ == '__main__':
-    connection = connect(host="44.200.35.172",
+    connection = connect(host="localhost",
                          port=9000,
                          scheme="e6xdb",
                          username="admin",
-                         database="tydy",
+                         database="tpcds_10gb",
                          auth=None,
                          configuration=None,
                          kerberos_service_name=None,
@@ -440,21 +440,46 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("SELECT offer_created_date from candidate_offer_letter limit 100;")
+    cursor.execute("SELECT * from catalog_sales limit 100000;")
     bdata = []
-    for i in range(10):
-        bdata += cursor.fetchmany()
     try:
-        # if len(bdata) < 1000:
-        for row in bdata:
-            print(row)
+        for i in range(1000):
+            bdata += cursor.fetchmany()
         print('total rows in the batch resultset ', len(bdata))
         r_count = cursor.rowcount()
         print('total row count', r_count)
-        # list(islice(iter(bdata, None), 10000))
     except Exception as e:
         print('Error Message ', e.__cause__)
-        cursor.close()
+
+    while True:
+        try:
+            connection = connect(host="localhost",
+                                 port=9000,
+                                 scheme="e6xdb",
+                                 username="admin",
+                                 database="tpcds_10gb",
+                                 auth=None,
+                                 configuration=None,
+                                 kerberos_service_name=None,
+                                 password="admin",
+                                 check_hostname=None,
+                                 ssl_cert=None,
+                                 thrift_transport=None)
+            cursor = Cursor(connection)
+            isOpen = cursor.connection.check_connection
+            if not isOpen:
+                time.sleep(5)
+                continue
+            else:
+                break
+        except:
+            time.sleep(5)
+            continue
+
+    cursor.execute("SELECT * from catalog_sales limit 100;")
+    bdata = []
+    for i in range(1000):
+        bdata += cursor.fetchmany()
 
 #
 # Type Objects and Constructors
